@@ -26,7 +26,7 @@ void my_gwibber_entry()
 
 	gtk_window_set_default_size(GTK_WINDOW(window), 400, 150);
 	gtk_window_set_title(GTK_WINDOW(window), "Gwibber Poster (C)");
-	GwibberEntry* entry = gwibber_entry_new ();
+	GwibberGtkEntry* entry = gwibber_gtk_entry_new ();
 	gtk_container_add ((GtkContainer*) window, (GtkWidget*) entry);
 	g_signal_connect(GTK_OBJECT(window), "destroy", G_CALLBACK(gtk_main_quit), NULL);
 
