@@ -27,7 +27,7 @@ public class GwibberPoster
 	{
 		Application.Init ();
 		Gtk.Window window = new Gtk.Window ("Gwibber Poster (Mono)");
-		Gwibber.Entry entry = new Gwibber.Entry ();
+		Gwibber.GtkEntry entry = new Gwibber.GtkEntry ();
 		window.Add (entry);
 		window.Resize (400, 150);
 		window.ShowAll ();
